@@ -1,6 +1,7 @@
 from .adept import *
 from .aidatatang_200zh import *
 from .aishell import *
+from .aishell2 import *
 from .aishell4 import *
 from .ali_meeting import *
 from .ami import *
@@ -15,6 +16,7 @@ from .cmu_indic import *
 from .cmu_kids import *
 from .commonvoice import *
 from .cslu_kids import *
+from .daily_talk import *
 from .dihard3 import *
 from .earnings21 import *
 from .earnings22 import *
@@ -33,16 +35,22 @@ from .librimix import *
 from .librispeech import *
 from .libritts import *
 from .ljspeech import *
+from .magicdata import *
 from .mgb2 import *
 from .mls import *
 from .mtedx import *
 from .musan import *
 from .nsc import *
 from .peoples_speech import *
+from .primewords import *
 from .rir_noise import *
 from .spgispeech import *
+from .stcmds import *
 from .switchboard import *
+from .tal_asr import *
+from .tal_csasr import *
 from .tedlium import *
+from .thchs_30 import *
 from .timit import *
 from .vctk import *
 from .voxceleb import *
