@@ -6,12 +6,11 @@ from lhotse.utils import Pathlike
 
 
 @prepare.command()
-@click.argument('tedlium_dir', type=click.Path(exists=True, dir_okay=True, file_okay=False))
-@click.argument('output_dir', type=click.Path())
-def tedlium(
-        tedlium_dir: Pathlike,
-        output_dir: Pathlike
-):
+@click.argument(
+    "tedlium_dir", type=click.Path(exists=True, dir_okay=True, file_okay=False)
+)
+@click.argument("output_dir", type=click.Path())
+def tedlium(tedlium_dir: Pathlike, output_dir: Pathlike):
     """
     TED-LIUM v3 recording and supervision manifest preparation.
     """
@@ -19,9 +18,7 @@ def tedlium(
 
 
 @download.command()
-@click.argument('target_dir', type=click.Path())
-def tedlium(
-        target_dir: Pathlike
-):
+@click.argument("target_dir", type=click.Path())
+def tedlium(target_dir: Pathlike):
     """TED-LIUM v3 download (approx. 11GB)."""
     download_tedlium(target_dir)
