@@ -72,10 +72,10 @@ class DynamicBucketingSampler(CutSampler):
         num_cuts_for_bins_estimate: int = 10000,
         buffer_size: int = 10000,
         shuffle_buffer_size: int = 20000,
-        strict: bool = True,
         world_size: Optional[int] = None,
         rank: Optional[int] = None,
         seed: int = 0,
+        strict=None,
     ) -> None:
         """
         :param cuts: one or more CutSets (when more than one, will yield tuples of CutSets as mini-batches)
@@ -105,11 +105,6 @@ class DynamicBucketingSampler(CutSampler):
         :param shuffle_buffer_size: How many cuts (or cut pairs, triplets) are being held in memory
             a buffer used for streaming shuffling. Larger number means better randomness at the cost
             of higher memory usage.
-        :param strict: When ``True``, for the purposes of determining dynamic batch size,
-            we take the longest cut sampled so far and multiply its duration/num_frames/num_samples
-            by the number of cuts currently in mini-batch to check if it exceeded max_duration/etc.
-            This can help make the GPU memory usage more predictable when there is a large variance
-            in cuts duration.
         :param world_size: Total number of distributed nodes. We will try to infer it by default.
         :param rank: Index of distributed node. We will try to infer it by default.
         :param seed: Random seed used to consistently shuffle the dataset across different processes.
@@ -131,9 +126,15 @@ class DynamicBucketingSampler(CutSampler):
         self.num_cuts_for_bins_estimate = num_cuts_for_bins_estimate
         self.buffer_size = buffer_size
         self.shuffle_buffer_size = shuffle_buffer_size
-        self.strict = strict
         self.rng = None
 
+        if strict is not None:
+            warnings.warn(
+                "In Lhotse v1.4 all samplers act as if 'strict=True'. "
+                "Sampler's argument 'strict' will be removed in a future Lhotse release.",
+                category=DeprecationWarning,
+            )
+
         if self.shuffle:
             cuts_for_bins_estimate = streaming_shuffle(
                 iter(self.cuts[0]),
@@ -157,7 +158,6 @@ class DynamicBucketingSampler(CutSampler):
                 "buffer_size": self.buffer_size,
                 "num_cuts_for_bins_estimate": self.num_cuts_for_bins_estimate,
                 "shuffle_buffer_size": self.shuffle_buffer_size,
-                "strict": self.strict,
             }
         )
         return sd
@@ -169,7 +169,7 @@ class DynamicBucketingSampler(CutSampler):
         self.num_cuts_for_bins_estimate = sd.pop("num_cuts_for_bins_estimate")
         self.buffer_size = sd.pop("buffer_size")
         self.shuffle_buffer_size = sd.pop("shuffle_buffer_size")
-        self.strict = sd.pop("strict")
+        sd.pop("strict", None)  # backward compatibility
         super().load_state_dict(sd)
         self._fast_forward()
 
@@ -222,7 +222,6 @@ class DynamicBucketingSampler(CutSampler):
             max_cuts=self.max_cuts,
             drop_last=self.drop_last,
             buffer_size=self.buffer_size,
-            strict=self.strict,
             rng=self.rng,
             diagnostics=self.diagnostics,
         )
@@ -298,7 +297,6 @@ class DynamicBucketer:
         max_cuts: Optional[int] = None,
         drop_last: bool = False,
         buffer_size: int = 10000,
-        strict: bool = False,
         rng: random.Random = None,
         diagnostics: Optional[SamplingDiagnostics] = None,
     ) -> None:
@@ -308,7 +306,6 @@ class DynamicBucketer:
         self.max_cuts = max_cuts
         self.drop_last = drop_last
         self.buffer_size = buffer_size
-        self.strict = strict
         self.diagnostics = ifnone(diagnostics, SamplingDiagnostics())
         if rng is None:
             rng = random.Random()
@@ -344,7 +341,6 @@ class DynamicBucketer:
             tot = TimeConstraint(
                 max_duration=self.max_duration,
                 max_cuts=self.max_cuts,
-                strict=self.strict,
             )
             for c in bucket:
                 tot.add(c[0] if isinstance(c, tuple) else c)
