@@ -36,10 +36,10 @@ class SimpleCutSampler(CutSampler):
         max_cuts: Optional[int] = None,
         shuffle: bool = False,
         drop_last: bool = False,
-        strict: bool = False,
         world_size: Optional[int] = None,
         rank: Optional[int] = None,
         seed: int = 0,
+        strict=None,
     ):
         """
         SimpleCutSampler's constructor.
@@ -54,11 +54,6 @@ class SimpleCutSampler(CutSampler):
             Convenient when mini-batch loop is inside an outer epoch-level loop, e.g.:
             `for epoch in range(10): for batch in dataset: ...` as every epoch will see a
             different cuts order.
-        :param strict: When ``True``, for the purposes of determining dynamic batch size,
-            we take the longest cut sampled so far and multiply its duration/num_frames/num_samples
-            by the number of cuts currently in mini-batch to check if it exceeded max_duration/etc.
-            This can help make the GPU memory usage more predictable when there is a large variance
-            in cuts duration.
         :param drop_last: When ``True``, the last batch is dropped if it's incomplete.
         :param world_size: Total number of distributed nodes. We will try to infer it by default.
         :param rank: Index of distributed node. We will try to infer it by default.
@@ -77,8 +72,13 @@ class SimpleCutSampler(CutSampler):
             max_frames=max_frames,
             max_samples=max_samples,
             max_cuts=max_cuts,
-            strict=strict,
         )
+        if strict is not None:
+            warnings.warn(
+                "In Lhotse v1.4 all samplers act as if 'strict=True'. "
+                "Sampler's argument 'strict' will be removed in a future Lhotse release.",
+                category=DeprecationWarning,
+            )
 
     @property
     def remaining_duration(self) -> Optional[float]:
@@ -189,7 +189,6 @@ class SimpleCutSampler(CutSampler):
                     not self.drop_last or self.time_constraint.close_to_exceeding()
                 ):
                     # We have a partial batch and we can return it.
-                    self.diagnostics.keep(cuts)
                     return CutSet.from_cuts(cuts)
                 else:
                     # There is nothing more to return or it's discarded:
@@ -227,7 +226,6 @@ class SimpleCutSampler(CutSampler):
                     )
                     cuts.append(next_cut)
 
-        self.diagnostics.keep(cuts)
         return CutSet.from_cuts(cuts)
 
 
