@@ -6,7 +6,7 @@ from typing import Dict, Optional, Sequence, Tuple, TypeVar, Union
 import numpy as np
 import torch
 
-from lhotse import CutSet
+from lhotse import CutSet, FeatureExtractor
 from lhotse.augmentation import dereverb_wpe_torch
 from lhotse.utils import Pathlike
 
@@ -23,8 +23,15 @@ class GlobalMVN(torch.nn.Module):
         self.register_buffer("norm_stds", torch.ones(feature_dim))
 
     @classmethod
-    def from_cuts(cls, cuts: CutSet, max_cuts: Optional[int] = None) -> "GlobalMVN":
-        stats = cuts.compute_global_feature_stats(max_cuts=max_cuts)
+    def from_cuts(
+        cls,
+        cuts: CutSet,
+        max_cuts: Optional[int] = None,
+        extractor: Optional[FeatureExtractor] = None,
+    ) -> "GlobalMVN":
+        stats = cuts.compute_global_feature_stats(
+            max_cuts=max_cuts, extractor=extractor
+        )
         stats = {name: torch.as_tensor(value) for name, value in stats.items()}
         (feature_dim,) = stats["norm_means"].shape
         global_mvn = cls(feature_dim)
