@@ -1,2 +1,2 @@
-from .extractors import KaldiFbank, KaldiFbankConfig, KaldiMfcc, KaldiMfccConfig
+from .extractors import Fbank, FbankConfig, Mfcc, MfccConfig
 from .layers import Wav2FFT, Wav2LogFilterBank, Wav2LogSpec, Wav2MFCC, Wav2Spec, Wav2Win
