@@ -6,7 +6,11 @@ from typing import Any, Callable, Dict, Optional, Tuple, Union
 import numpy as np
 
 from lhotse.array import Array, TemporalArray
-from lhotse.audio import Recording, RecordingSet
+from lhotse.audio import (
+    LHOTSE_AUDIO_DURATION_MISMATCH_TOLERANCE,
+    Recording,
+    RecordingSet,
+)
 from lhotse.cut import Cut, CutSet, MixedCut, MonoCut, PaddingCut
 from lhotse.features import Features, FeatureSet
 from lhotse.supervision import SupervisionSegment, SupervisionSet
@@ -210,7 +214,9 @@ def validate_recording(r: Recording, read_data: bool = False) -> None:
     ), f"Recording {r.id}: duration has to be greater than 0 (is {r.duration})"
     expected_duration = r.num_samples / r.sampling_rate
     assert r.num_channels > 0, f"Recording {r.id}: no channels available"
-    assert isclose(expected_duration, r.duration), (
+    assert (
+        abs(expected_duration - r.duration) <= LHOTSE_AUDIO_DURATION_MISMATCH_TOLERANCE
+    ), (
         f"Recording {r.id}: mismatched declared duration ({r.duration}) with "
         f"num_samples / sampling_rate ({expected_duration})."
     )
