@@ -16,6 +16,8 @@ from collections import defaultdict
 from pathlib import Path
 from typing import Dict, Optional, Union
 
+from tqdm.auto import tqdm
+
 from lhotse import validate_recordings_and_supervisions
 from lhotse.audio import Recording, RecordingSet
 from lhotse.supervision import SupervisionSegment, SupervisionSet
@@ -91,13 +93,19 @@ def prepare_aidatatang_200zh(
     with open(transcript_path, "r", encoding="utf-8") as f:
         for line in f.readlines():
             idx_transcript = line.split()
-            transcript_dict[idx_transcript[0]] = " ".join(idx_transcript[1:])
+            content = " ".join(idx_transcript[1:])
+            content = content.replace("Ａ", "A")
+            content = content.upper()
+            transcript_dict[idx_transcript[0]] = content
     manifests = defaultdict(dict)
     dataset_parts = ["dev", "test", "train"]
 
-    for part in dataset_parts:
+    for part in tqdm(
+        dataset_parts,
+        desc="Process aidatatang audio, it takes about 2559 seconds.",
+    ):
         # Generate a mapping: utt_id -> (audio_path, audio_info, speaker, text)
-        logging.info(f"Processing {part}")
+        logging.info(f"Processing  prepare_aidatatang_200zh subset: {part}")
         recordings = []
         supervisions = []
         wav_path = d / "corpus" / part
@@ -106,6 +114,7 @@ def prepare_aidatatang_200zh(
             speaker = audio_path.parts[-2]
             if idx not in transcript_dict:
                 logging.warning(f"No transcript: {idx}")
+                logging.warning(f"{audio_path} has no transcript. ")
                 continue
             text = transcript_dict[idx]
             if not audio_path.is_file():
