@@ -209,8 +209,12 @@ def prepare_callhome_english_asr(
         if output_dir is not None:
             output_dir = Path(output_dir)
             output_dir.mkdir(parents=True, exist_ok=True)
-            recordings.to_json(output_dir / f"recordings_{split}.json")
-            supervisions.to_json(output_dir / f"supervisions_{split}.json")
+            recordings.to_file(
+                output_dir / f"callhome-english_recordings_{split}.jsonl.gz"
+            )
+            supervisions.to_file(
+                output_dir / f"callhome-english_supervisions_{split}.jsonl.gz"
+            )
 
         manifests[split] = {"recordings": recordings, "supervisions": supervisions}
 
